A complete library for Rubino(Rubika)

## Install
``` bash
pip install rubino_rubika
```

<hr>

## Example
``` python
from rubino_rubika import Rubino

bot = Rubino("Auth", "Profile_id")

print(bot.get_my_profile_info())

bot.add_comment("post_id", "post_profile_id", "text")
```

<hr>

## Do you have a problem?
### <a href='https://rubika.ir/amir_ershadi_2'>click</a>